Module controller

Module controller 

Implementations of a controller for wind propulsion devices intended to be used together with the simulation models in the library.

Modules

builder
input
measurements
output
prelude
set_points

Structs

Controller