Module error
stormbird
0.8.0
Module error
Module Items
Enums
In crate stormbird
stormbird
Module
error
An implementation of a common error type that is used throughout the library.
Enums

Error
A common error type intended to represent the various error that can occur while suing this library.